summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmlibraryhandle.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pmlibraryhandle.h')
-rw-r--r--kpovmodeler/pmlibraryhandle.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kpovmodeler/pmlibraryhandle.h b/kpovmodeler/pmlibraryhandle.h
index 2263407e..e20d6368 100644
--- a/kpovmodeler/pmlibraryhandle.h
+++ b/kpovmodeler/pmlibraryhandle.h
@@ -181,10 +181,10 @@ public:
/**
* Changes the tqparent library if this is a sub library
* @param tqparentPath The new tqparent path for this library
* @return PMLibraryHandle::Ok if successful or the reason for failure
*/
- PMLibraryHandle::PMResult changeParentLibrary( const TQString& tqparentPath );
+ PMLibraryHandle::PMResult changeParentLibrary( const TQString& parentPath );
private:
@@ -181,10 +181,10 @@ public:
/**
* Changes the tqparent library if this is a sub library
- * @param tqparentPath The new tqparent path for this library
+ * @param parentPath The new tqparent path for this library
* @return PMLibraryHandle::Ok if successful or the reason for failure
*/